﻿using System;
using System.Collections.ObjectModel;
using System.Globalization;
using System.IO;
using System.Threading;
using System.Windows;
using System.Windows.Data;
using System.Windows.Media.Imaging;
using Infralution.Localization.Wpf;
using Microsoft.Win32;
using Syncfusion.UI.Xaml.Charts;
using Testing_WFP_Charts.Properties;

namespace Testing_WFP_Charts
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            //CultureManager.UICulture = new CultureInfo("es");
            
            const bool showSensitivity = true;
            DateTime? therapyStartDate = new DateTime(2015, 2, 1);//null;//
            var rampInDate = new DateTime(2014, 11, 1);
            var rampOutDate = new DateTime(2016, 9, 1);

            ViewModel = new ChartVm
            {
                RampOutDate = rampOutDate,
                RampInDate = rampInDate,
                TherapyStartDate = therapyStartDate,
                ShowSensitivity = showSensitivity,
                ChartData = new ObservableCollection<ChartDataItem>
                {
                    new ChartDataItem
                    {
                        Date = new DateTime(2015, 1, 1),
                        Sensitivity = (decimal?) 0.5,
                        SampleResult = 200,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "200",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false

                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2015, 3, 1),
                        Sensitivity = (decimal?) 0.05,
                        SampleResult = 95,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "95",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false
                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2015, 6, 1),
                        Sensitivity = (decimal?) 0.05,
                        SampleResult = 60,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "60",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false
                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2015, 9, 1),
                        Sensitivity = (decimal) 0.1,
                        SampleResult = (decimal) 0.5,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "0.5",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false
                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2016, 1, 1),
                        Sensitivity = null,
                        SampleResult = null,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "Sample Failure",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = true
                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2016, 3, 1),
                        Sensitivity = (decimal) 0.005,
                        SampleResult = (decimal) 0.001,
                        IsUndedectable = true,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "Undetectable",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false
                    },
                    new ChartDataItem
                    {
                        Date = new DateTime(2016, 6, 1),
                        Sensitivity = (decimal) 0.005,
                        SampleResult = (decimal) 0.005,
                        IsUndedectable = false,
                        ShowSensitivity = showSensitivity,
                        SampleResultString = "0.005",
                        SampleType = "Peripheral Blood (PB)",
                        IsSampleFailed = false
                    }
                }
            };

            if (ViewModel.HasTherapy)
            {
                ViewModel.BackgroundArea = new ObservableCollection<RangeAreaChartDataItem>
                {
                    new RangeAreaChartDataItem {Date = therapyStartDate.Value, High = 100, Low = (decimal?) 0.001},
                    new RangeAreaChartDataItem
                    {
                        Date = therapyStartDate.Value.AddMonths(3),
                        High = 10,
                        Low = (decimal?) 0.001
                    },
                    new RangeAreaChartDataItem
                    {
                        Date = therapyStartDate.Value.AddMonths(6),
                        High = 10,
                        Low = (decimal?) 0.001
                    },
                    new RangeAreaChartDataItem
                    {
                        Date = therapyStartDate.Value.AddMonths(9),
                        High = 1,
                        Low = (decimal?) 0.001
                    },
                    new RangeAreaChartDataItem
                    {
                        Date = therapyStartDate.Value.AddMonths(12),
                        High = (decimal?) 0.1,
                        Low = (decimal?) 0.001
                    },
                    new RangeAreaChartDataItem {Date = rampOutDate, High = (decimal?) 0.1, Low = (decimal?) 0.001},
                };
            }

            if (!ViewModel.HasTherapy)
            {
                TherapyStartLineAnnotation.Visibility = Visibility.Collapsed;
                DateTimeAxis.PlotOffset = 90;
            }

            if (!ViewModel.ShowSensitivity)
            {
                SensitivitySeries.Visibility = Visibility.Hidden;
                SensitivitySeries.VisibilityOnLegend = Visibility.Hidden;
            }
        }

        public ChartVm ViewModel { get; set; }
        
        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            //MyChart.Save("chart_image.png");

            SaveFileDialog sfd = new SaveFileDialog();
            sfd.FileName = "Untitled";
            sfd.Filter =
                "PNG(*.png)|*.png|Bitmap(*.bmp)|*.bmp|JPEG(*.jpg,*.jpeg)|*.jpg;*.jpeg|Gif (*.gif)|*.gif|All files (*.*)|*.*";
            if (sfd.ShowDialog() == true)
            {
                using (Stream fs = sfd.OpenFile())
                {
                    MyChart.Save(fs, new PngBitmapEncoder());
                }
            }
        }

        private void SpanishButton_OnClick(object sender, RoutedEventArgs e)
        {
            CultureManager.UICulture = new CultureInfo("es");
            
        }

        private void EnglishButton_OnClick(object sender, RoutedEventArgs e)
        {
            CultureManager.UICulture = new CultureInfo("en");
        }

        private void SpanishButton_OnClick2(object sender, RoutedEventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("es-ES");
            Thread.CurrentThread.CurrentCulture = Thread.CurrentThread.CurrentUICulture;

            var newWindow = new StartupWindow();
            newWindow.Show();
            Close();
        }

        private void EnglishButton_OnClick2(object sender, RoutedEventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("en");
            Thread.CurrentThread.CurrentCulture = Thread.CurrentThread.CurrentUICulture;

            var newWindow = new StartupWindow();
            newWindow.Show();
            Close();
        }
    }

    public class ChartVm
    {
        public ChartVm()
        {
            BackgroundArea = new ObservableCollection<RangeAreaChartDataItem>();
        }

        public ObservableCollection<ChartDataItem> ChartData { get; set; }
        public ObservableCollection<RangeAreaChartDataItem> BackgroundArea { get; set; }
        public DateTime RampInDate { get; set; }
        public DateTime RampOutDate { get; set; }
        public DateTime? TherapyStartDate { get; set; }
        public bool ShowSensitivity { get; set; }

        public bool HasTherapy
        {
            get { return TherapyStartDate.HasValue; }
        }
}

    public class ChartDataItem
    {
        public DateTime Date { get; set; }
        public decimal? SampleResult { get; set; }
        public string SampleResultString { get; set; }
        public string SampleType { get; set; }
        public decimal? Sensitivity { get; set; }
        public bool IsUndedectable { get; set; }
        public bool ShowSensitivity { get; set; }
        public bool IsSampleFailed { get; set; }
    }

    public class RangeAreaChartDataItem
    {
        public DateTime Date { get; set; }
        public decimal? High { get; set; }
        public decimal? Low { get; set; }
    }

    public class ChartDateConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var chartPointInfo = value as ChartPointInfo;
            var chartPoint = chartPointInfo.Item as ChartDataItem;

            DateTime dateTime = chartPoint.Date;
            var data = dateTime.GetDateTimeFormats();
            return data[8];
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ChartSampleResultConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var chartPointInfo = value as ChartPointInfo;
            var chartPoint = chartPointInfo.Item as ChartDataItem;

            if (chartPoint.IsUndedectable)
                return Resources.Shared_Report_Result_Undetected;

            return string.Format("{0}%", chartPoint.SampleResult.RemoveTrailingZeros());
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ChartSensitivityConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var chartPointInfo = value as ChartPointInfo;
            var chartPoint = chartPointInfo.Item as ChartDataItem;

            return string.Format("{0}%", chartPoint.Sensitivity.RemoveTrailingZeros());
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ChartTooltipShowSensitivityToVisConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            try
            {
                var chartPointInfo = value as ChartPointInfo;
                var chartPoint = chartPointInfo.Item as ChartDataItem;

                if (chartPoint.ShowSensitivity)
                {
                    return Visibility.Visible;
                }
                return Visibility.Collapsed;
            }
            catch
            {
                return Visibility.Collapsed;
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }


/// <summary>
    /// Decimal Extensions Class.
    /// </summary>
    public static class DecimalExtensions
    {
        public static string RemoveTrailingZeros(this decimal? dt)
        {
            if (!dt.HasValue) return "";
            return dt.Value.ToString("0.##########", CultureInfo.InvariantCulture);
        }
    }

}
